"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.initializePackageManager = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = require("path");

var _chalk = _interopRequireDefault(require("chalk"));

var _exec = require("./exec");

var _utils = require("./utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/* eslint no-console: 0 */
const initializePackageManager = // eslint-disable-next-line
async (pkgManager, projectName, orgScope, projectDescription, repoOwner) => {
  if (pkgManager === 'npm') {
    const scopedProject = orgScope === 'none' ? null : `@${orgScope}/${projectName}`;
    const {
      stdout,
      stderr
    } = await (0, _exec.shellExec)(`npm init -y --force`);
    const outputstring = stdout.replace(`Wrote to ${process.cwd()}/package.json:\n\n`, '');
    const pkg = JSON.parse(outputstring);
    const outFileName = (0, _path.join)(process.cwd(), 'package.json');
    const description = (0, _utils.parseDescription)(projectDescription, projectName);

    const newPkg = _objectSpread({}, pkg.pkg, {
      name: scopedProject ? scopedProject : projectName,
      version: '0.0.0-semantically-released',
      private: false,
      description,
      license: 'MIT',
      engines: {
        node: '>=10.0.0'
      },
      scripts: undefined,
      repository: repoOwner ? {
        type: 'git',
        url: `git+https://github.com/${repoOwner}/${projectName}.git`
      } : undefined,
      bugs: repoOwner ? {
        url: `https://github.com/${repoOwner}/${projectName}/issues`
      } : undefined,
      homepage: repoOwner ? `https://github.com/${repoOwner}/${projectName}#readme` : undefined
    }); // eslint-disable-next-line


    const json = JSON.stringify(newPkg, null, 4);
    console.log(_chalk.default.green('------ Wrote NPM package.json ------'));
    console.log(_chalk.default.green(json));

    if (stderr.includes('npm WARN using --force')) {
      console.log(_chalk.default.yellow(stderr));
    } else if (stderr) {
      console.log(_chalk.default.red(stderr));
    }

    _fs.default.writeFileSync(outFileName, json);

    _fs.default.chmodSync(outFileName, '755');
  }
};

exports.initializePackageManager = initializePackageManager;