"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.runTasks = void 0;

var _chalk = _interopRequireDefault(require("chalk"));

var _packageManager = require("./package-manager");

var _backendManager = require("./backend-manager");

var _sourceManager = require("./source-manager");

var _multienvManager = require("./multienv-manager");

var _readme = require("./readme");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const taskFunctions = {
  initPackageManager: _packageManager.initializePackageManager,
  initSourceControlManager: _sourceManager.initializeSourceControlManager,
  initBackendManager: _backendManager.initializeBackendManager,
  initMultienvManager: _multienvManager.initializeMultiEnvManager,
  initGlobalBackend: _backendManager.installBackendGlobally,
  initReadme: _readme.initializeReadme
};

const runTasks = async tasks => {
  for (const task of tasks) {
    // eslint-disable-next-line
    console.log(_chalk.default.blue(`------ ${task.description.toUpperCase()} ------`));
    await taskFunctions[task.type](...task.args);
  }
};

exports.runTasks = runTasks;