"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createAmplifyInitScriptWithEnv = exports.parseMaintainers = exports.parseDescription = void 0;

var _fs = _interopRequireDefault(require("fs"));

var _path = require("path");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const parseDescription = (description, name) => {
  if (description.includes('<project name>')) {
    return description.replace('<project name>', name);
  }

  return description;
};

exports.parseDescription = parseDescription;

const parseMaintainers = maintainers => {
  if (maintainers === 'none') {
    return '';
  }

  const usernames = maintainers.split(',');
  let maintainerString = '';

  for (const name of usernames) {
    const whiteSpaceFreeName = name.replace(/\s/g, '');
    const attribute = `[@${whiteSpaceFreeName}](https://github.com/${whiteSpaceFreeName})\n`;
    maintainerString += attribute;
  }

  return maintainerString;
}; // eslint-disable-next-line


exports.parseMaintainers = parseMaintainers;

const createAmplifyInitScriptWithEnv = env => {
  const templateDir = (0, _path.join)((0, _path.dirname)(process.argv[1]), 'templates');
  const tempDir = (0, _path.join)((0, _path.dirname)(process.argv[1]), 'temp');
  const headlessInitScriptPath = (0, _path.join)(templateDir, 'headless-amplify-init.sh');

  const scriptString = _fs.default.readFileSync(headlessInitScriptPath, 'utf8');

  const tempScript = scriptString.replace('<?amplifyEnv?>', env);
  const tempScriptPath = (0, _path.join)(tempDir, 'headless-amplify-init.sh');

  if (!_fs.default.existsSync(tempDir)) {
    _fs.default.mkdirSync(tempDir);
  }

  _fs.default.writeFileSync(tempScriptPath, tempScript);

  _fs.default.chmodSync(tempScriptPath, '755');

  return tempScriptPath;
};

exports.createAmplifyInitScriptWithEnv = createAmplifyInitScriptWithEnv;